@@ -2,10 +2,7 @@ use std::{sync::mpsc::Receiver, time::Duration};
 
 use serde_derive::Deserialize;
 
-use crate::{
-    framework::{BootstrapResult, SinkConfig},
-    ports::Event,
-};
+use crate::framework::{BootstrapResult, Event, SinkConfig};
 
 use super::run::reducer_loop;
 
